summaryrefslogtreecommitdiff
path: root/nuttx/sched/sig_timedwait.c
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2013-02-04 18:46:28 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2013-02-04 18:46:28 +0000
commit7071ca9d21d783827f93fcd25631aa2da8df8fe4 (patch)
tree1fab8982b4f2438b1b135fd6c43e7b8a8af78d48 /nuttx/sched/sig_timedwait.c
parent09afe06037de8f89b2cfa4f1765be407bf1783a2 (diff)
downloadpx4-nuttx-7071ca9d21d783827f93fcd25631aa2da8df8fe4.tar.gz
px4-nuttx-7071ca9d21d783827f93fcd25631aa2da8df8fe4.tar.bz2
px4-nuttx-7071ca9d21d783827f93fcd25631aa2da8df8fe4.zip
Rename _TCB to struct tcb_s
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@5610 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'nuttx/sched/sig_timedwait.c')
-rw-r--r--nuttx/sched/sig_timedwait.c20
1 files changed, 10 insertions, 10 deletions
diff --git a/nuttx/sched/sig_timedwait.c b/nuttx/sched/sig_timedwait.c
index f8c619b21..21e40f170 100644
--- a/nuttx/sched/sig_timedwait.c
+++ b/nuttx/sched/sig_timedwait.c
@@ -1,7 +1,7 @@
/****************************************************************************
* sched/sig_timedwait.c
*
- * Copyright (C) 2007-2009, 2012 Gregory Nutt. All rights reserved.
+ * Copyright (C) 2007-2009, 2012-2013 Gregory Nutt. All rights reserved.
* Author: Gregory Nutt <gnutt@nuttx.org>
*
* Redistribution and use in source and binary forms, with or without
@@ -93,15 +93,15 @@
static void sig_timeout(int argc, uint32_t itcb)
{
/* On many small machines, pointers are encoded and cannot be simply cast
* from uint32_t to _TCB*. The following union works around this
* (see wdogparm_t). This odd logic could be conditioned on
* CONFIG_CAN_CAST_POINTERS, but it is not too bad in any case.
*/
union
{
- FAR _TCB *wtcb;
- uint32_t itcb;
+ FAR struct tcb_s *wtcb;
+ uint32_t itcb;
} u;
u.itcb = itcb;
@@ -178,13 +178,13 @@ static void sig_timeout(int argc, uint32_t itcb)
int sigtimedwait(FAR const sigset_t *set, FAR struct siginfo *info,
FAR const struct timespec *timeout)
{
- FAR _TCB *rtcb = (FAR _TCB*)g_readytorun.head;
- sigset_t intersection;
+ FAR struct tcb_s *rtcb = (FAR struct tcb_s*)g_readytorun.head;
+ sigset_t intersection;
FAR sigpendq_t *sigpend;
- WDOG_ID wdog;
- irqstate_t saved_state;
- int32_t waitticks;
- int ret = ERROR;
+ WDOG_ID wdog;
+ irqstate_t saved_state;
+ int32_t waitticks;
+ int ret = ERROR;
sched_lock(); /* Not necessary */
@@ -93,15 +93,15 @@
{
/* On many small machines, pointers are encoded and cannot be simply cast
- * from uint32_t to _TCB*. The following union works around this
+ * from uint32_t to struct tcb_s*. The following union works around this
* (see wdogparm_t). This odd logic could be conditioned on
* CONFIG_CAN_CAST_POINTERS, but it is not too bad in any case.